package vulnerability

import grypeDB "github.com/anchore/grype/grype/db/v3"

const SchemaVersion = grypeDB.SchemaVersion
